pilot.api.data.api.DataUnitService

Package pilot :: Package api :: Package data :: Module api :: Class DataUnitService |

# Class DataUnitService

source code

DataUnitService (DUS).

Please use ComputeDataService

Instance Methods
__init__(self, pds_id=None) Create a DataUnitService. | source code
add_pilot_data_service(self, pss) Add a PilotDataService | source code
remove_pilot_data_service(self, pss) Remove a PilotDataService | source code
list_pilot_data(self) List all PDs of PDS | source code
submit_pilot_data_set(self, data_unit_description) Create Pilot Data object and schedule it to a Pilot Data | source code
cancel(self) Cancel the PDS. | source code
get_state(self) | source code
get_id(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, pds_id=None) (Constructor) | source code
Create a DataUnitService. Keyword arguments: pds_id -- Reconnect to an existing DataUnitService Overrides: object.__init__

### add_pilot_data_service(self, pss) | source code
Add a PilotDataService Keyword arguments: pss -- The PilotDataService to add. Return: Result

### remove_pilot_data_service(self, pss) | source code
Remove a PilotDataService Keyword arguments: pss -- The PilotDataService to remove Return: Result

### cancel(self) | source code
Cancel the PDS. Keyword arguments: None Return: Result